<?php
/**
 * Setting up the plugin admin page configuration/options.
 *
 * @return void
 */
if ( !function_exists( 'rtp_plgn_main_menu' ) ) {
	function rtp_plgn_main_menu() {
		global $aft_options_array, $aft_options_by_array;
		
		$aft_message = "";
		
		//Accept the changes for the plugin options
		if ( isset( $_REQUEST['aft_plgn_submit_options'] ) ) {	
			$aft_options_array['aft_is_enable'] = $_REQUEST['aft_is_enable'];
			$aft_options_array['aft_location'] = $_REQUEST['aft_location'];
			$aft_options_array['aft_insertion'] = $_REQUEST['rtp-insertion'];
			
			update_option( 'aft_options_array', $aft_options_array );
			$aft_message = "Option Saved!";
		}
		
		if ( isset( $_REQUEST['submit-insertion'] ) ) {
			$cat_id = get_all_category_ids();
			$page_id = get_all_page_ids();

			$options_category = array();
			$options_page = array();

			// by category
			if ( $cat_id ) {
				$i = 0;
				foreach( $cat_id as $id ) {
					$options_category[get_cat_name($id)] = ( isset( $_REQUEST['aft-category-check-'.$i.''] ) ) ? $_REQUEST['aft-category-check-'.$i.''] : 0;
					$i++;
				}
			}
			
			// by page
			if ( $page_id ) {
				$i = 0;
				foreach( $page_id as $id ) {
					$page_data = get_page( $id );
					$options_page[$page_data->post_title] = ( isset( $_REQUEST['aft-page-check-'.$i.''] ) ) ? $_REQUEST['aft-page-check-'.$i.''] : 0;
					$i++;
				}
			}
			
			$aft_options_by_array['category'] = $options_category;
			$aft_options_by_array['page'] = $options_page;
			
			update_option( 'aft_options_by_array', $aft_options_by_array );
			$aft_message = "Insertion Options Saved!";
		}
		
		if ( isset( $_REQUEST['rtp-uninstall-table'] ) ) {
			remove_table();
			$aft_message = "Successfully Drop Tables!";			
		} else if ( isset( $_REQUEST['rtp-install-table'] ) ) {
			create_table();
			$aft_message = "Successfully Created Tables!";
		}

		//Load Admin Setting Page
		rtp_plgn_menu_template( $aft_message, $aft_options_array, $aft_options_by_array );
	}
}

/**
 * Admin settings format design
 *
 * @param string $message
 * @param array @options
 * @param array @options_by
 *
 * @return void
 */
if ( !function_exists( 'rtp_plgn_menu_template' ) ) {
	function rtp_plgn_menu_template( $message, $options, $options_by ) {
		global $wpdb, $title;
		
		$tbl_feedbacks = $wpdb->prefix . "feedbacks";
		$tbl_feedbacks_summary = $wpdb->prefix . "feedbacks_summary";
	
		$cat_id = get_all_category_ids();
		$page_id = get_all_page_ids();
		?>
<script>
	jQuery(document).ready(function() {
		jQuery(".tabs").tabs();
		
		jQuery("#report-result").tablesorter({ 
			sortList: [[0,0]],
			headers: {
				2: { sorter: false },
				3: { sorter: false },
				4: { sorter: false },
				5: { sorter: false }
			}
		});
		
		jQuery("#insertion-by-category").tablesorter({
			sortList: [[1,0]],
			headers: {0: { sorter: false } }
		});	
		
		jQuery("#insertion-by-page").tablesorter({
			sortList: [[1,0]],
			headers: {0: { sorter: false } }
		});	
		
		jQuery("#insertion-category").tablesorter({
			sortList: [[1,0]],
			headers: {0: { sorter: false } }
		});	
		
		jQuery("#insertion-page").tablesorter({
			sortList: [[1,0]],
			headers: {0: { sorter: false } }
		});	
	});
</script>
<div class="wrap">
	<div id="rtp-logo-title" class="icon32"></div>
	<h2><?php echo $title; ?></h2>
	<div id="message" class="updated"
	<?php if( ! isset( $_REQUEST['aft_plgn_submit_options'] ) || $error != "" ) echo "style=\"display:none\""; ?>>
	<p><strong><?php echo $message; ?></strong></p></div>
	<div class="tabs">
		<ul class="rtp-tab-navigation">
			<li><a href="#rtp-configuration">Configuration</a></li>
			<li <?php if ( $options['aft_insertion'] != 'by-page' ) echo "style='display:none;'" ?>><a href='#rtp-insertion'>By Page Insertion</a></li>
			<li <?php if ( $options['aft_insertion'] != 'by-category' ) echo "style='display:none;'" ?>><a href='#rtp-insertion'>By Category Insertion</a></li>
			<li <?php if ( $options['aft_insertion'] != 'page-category' ) echo "style='display:none;'" ?>><a href='#rtp-insertion'>Insertion For Both</a></li>
			<li><a href="#rtp-reporting">Ratings Report</a></li>
			<li><a href="#rtp-db-configuration">Database Configuration</a></li>
		</ul>
		<div id="rtp-configuration">
			<div>
				<form name="frmoptions" method="post" action="admin.php?page=<?php echo RTP_PLUGIN_SNAME; ?>" enctype="multipart/form-data" >
					<table class="rtp-form-table">
						<tr>
							<th>Display Plugin:</th>
							<td>
								<select name="aft_is_enable" style="width: 120px;">
									<option <?php if ( $options['aft_is_enable'] == 'false' ) echo 'selected=""' ?> value="false">No</option>
									<option <?php if ( $options['aft_is_enable'] == 'true' ) echo 'selected=""' ?> value="true">Yes</option>
								</select>
							</td>
						</tr>
						<tr>
							<th>Plugin Insertion: </th>
							<td>
								<div class="rtp-insertion-scrollbox corners">
									<ul>
										<li>
											<input type="radio" id="rtp-all-article" name="rtp-insertion" value="all-article" <?php if ( $options['aft_insertion'] == 'all-article' ) echo "checked=''" ?> />
											<label for="rtp-all-article">All Article</label>
										</li>
										<li>
											<input type="radio" id="rtp-by-page" name="rtp-insertion" value="by-page" <?php if ( $options['aft_insertion'] == 'by-page' ) echo "checked=''" ?> />
											<label for="rtp-by-page">By Page</label>
										</li>
										<li>
											<input type="radio" id="rtp-by-category" name="rtp-insertion" value="by-category" <?php if ( $options['aft_insertion'] == 'by-category' ) echo "checked=''" ?> />
											<label for="rtp-by-category">By Category</label>
										</li>
										<li>
											<input type="radio" id="rtp-page-category" name="rtp-insertion" value="page-category" <?php if ( $options['aft_insertion'] == 'page-category' ) echo "checked=''" ?> />
											<label for="rtp-page-category">By Page and Category</label>
										</li>
									</ul>
								</div>
							</td>
						</tr>
						<tr>
							<th>Plugin Position:</th>
							<td>
								<select name="aft_location" style="width: 120px;">
									<option <?php if ( $options['aft_location'] == 'top' ) echo 'selected="selected"' ?> value="top">Top</option>
									<option <?php if ( $options['aft_location'] == 'bottom' ) echo 'selected="selected"' ?> value="bottom">Bottom</option>
								</select>
							</td>
						</tr>
						<tr>
							<td><input class="button-primary" type="submit" value="<?php _e( 'Save Changes' ); ?>" /></td>
						</tr>
						<input type="hidden" name="aft_plgn_submit_options" value="submit" />
					</table>
				</form>
			</div>
		</div>
		<div id="rtp-insertion">
			<form method="post" action="admin.php?page=<?php echo RTP_PLUGIN_SNAME; ?>#rtp-insertion" enctype="multipart/form-data" >
				<div class="rtp-label-top">
					<input class="button-secondary" name="submit-insertion" type="submit" value="<?php _e( 'Apply Insertion' ); ?>" />
				</div>
				<?php if ( $options['aft_insertion'] == 'by-category' ) : ?>
				<table id="insertion-by-category" class="tablesorter">
					<thead>
						<th id="cb" class="manage-column column-cb check-column" style="" scope="col" width="20" align="center">
							<input type="checkbox" class="aft-all-category" />
						</th>
						<th>ID</th>
						<th>Name</th>
						<th>Description</th>
						<th>Slug</th>
					</thead>
					<tbody>
						<?php
							$cat_opt_id = array();
							foreach( $options_by['category'] as $category ) {
								$cat_opt_id[] = $category;
							}
						?>
						<?php $i = 0; ?>
						<?php foreach ( $cat_id as $id ) : ?>
						<?php $cat_arr = get_category($id); ?>
						<tr>
							<th class="check-column" scope="row" align="center">
							<input id="aft-category-check-<?php echo $i; ?>" type="checkbox" name="aft-category-check-<?php echo $i; ?>" value="<?php echo $cat_arr->term_id; ?>" <?php if ( $cat_arr->term_id == $cat_opt_id[$i] ) echo 'checked="checked"'; ?> />
							</th>
							<td><?php echo $cat_arr->term_id; ?></td>
							<td><?php echo $cat_arr->name; ?></td>
							<td><?php echo $cat_arr->description; ?></td>
							<td><?php echo $cat_arr->slug; ?></td>
						</tr>
						<?php $i++; ?>
						<?php endforeach; ?>
					</tbody>
				</table>
				<div id="category-navigation"></div>
				<script type="text/javascript">
					var cat_pager = new Pager('insertion-by-category', 10); 
					cat_pager.init(); 
					cat_pager.showPageNav('cat_pager', 'category-navigation'); 
					cat_pager.showPage(1);
				</script>
				<?php elseif ( $options['aft_insertion'] == 'by-page' ) : ?>
				<table id="insertion-by-page" class="tablesorter">
					<thead>
						<th id="cb" class="manage-column column-cb check-column" style="" scope="col" width="20" align="center">
							<input type="checkbox" id="aft-all-page" />
						</th>
						<th>ID</th>
						<th>Title</th>
						<th>Slug</th>
					</thead>
					<tbody>
						<?php
							$page_opt_id = array();
							foreach ( $options_by['page'] as $page ) {
								$page_opt_id[] = $page;
							}
						?>
						<?php $i = 0; ?>
						<?php foreach ( $page_id as $id ) : ?>
						<?php $page_data = get_page( $id ); ?>
						<tr>
							<th class="check-column" scope="row" align="center">
								<input id="aft-page-check-<?php echo $i; ?>" type="checkbox" name="aft-page-check-<?php echo $i; ?>" value="<?php echo $id; ?>" <?php if ( $id == $page_opt_id[$i] ) echo 'checked="checked"'; ?> />
							</th>
							<td><?php echo $page_data->ID; ?></td>
							<td><?php echo $page_data->post_title; ?></td>
							<td><?php echo $page_data->post_name; ?></td>
						</tr>
						<?php $i++; ?>
						<?php endforeach; ?>
					</tbody>
				</table>
				<div id="page-navigation"></div>
				<script type="text/javascript">
					var page_pager = new Pager('insertion-by-page', 10); 
					page_pager.init(); 
					page_pager.showPageNav('page_pager', 'page-navigation'); 
					page_pager.showPage(1);
				</script>
				<?php else: ?>
				<div style="clear: both;"></div>
				<div>
					<fieldset>
						<legend><b>Category List</b></legend>
						<table id="insertion-category" class="tablesorter">
							<thead>
								<th id="cb" class="manage-column column-cb check-column" style="" scope="col" width="20" align="center">
									<input type="checkbox" class="aft-all-category" />
								</th>
								<th>ID</th>
								<th>Name</th>
								<th>Description</th>
								<th>Slug</th>
							</thead>
							<tbody>
								<?php
									$cat_opt_id = array();
									foreach( $options_by['category'] as $category ) {
										$cat_opt_id[] = $category;
									}
								?>
								<?php $i = 0; ?>
								<?php foreach ( $cat_id as $id ) : ?>
								<?php $cat_arr = get_category($id); ?>
								<tr>
									<th class="check-column" scope="row" align="center">
									<input id="aft-category-check-<?php echo $i; ?>" type="checkbox" name="aft-category-check-<?php echo $i; ?>" value="<?php echo $cat_arr->term_id; ?>" <?php if ( $cat_arr->term_id == $cat_opt_id[$i] ) echo 'checked="checked"'; ?> />
									</th>
									<td><?php echo $cat_arr->term_id; ?></td>
									<td><?php echo $cat_arr->name; ?></td>
									<td><?php echo $cat_arr->description; ?></td>
									<td><?php echo $cat_arr->slug; ?></td>
								</tr>
								<?php $i++; ?>
								<?php endforeach; ?>
							</tbody>
						</table>
						<div id="category-navigation"></div>
					</fieldset>
					<script type="text/javascript">
						var cat_pager = new Pager('insertion-category', 10); 
						cat_pager.init(); 
						cat_pager.showPageNav('cat_pager', 'category-navigation'); 
						cat_pager.showPage(1);
					</script>
				</div>
				<br />
				<div>
					<fieldset>
						<legend><b>Page Lists</b></legend>
						<table id="insertion-page" class="tablesorter">
							<thead>
								<th id="cb" class="manage-column column-cb check-column" style="" scope="col" width="20" align="center">
									<input type="checkbox" id="aft-all-page" />
								</th>
								<th>ID</th>
								<th>Title</th>
								<th>Slug</th>
							</thead>
							<tbody>
								<?php
									$page_opt_id = array();
									foreach ( $options_by['page'] as $page ) {
										$page_opt_id[] = $page;
									}
								?>
								<?php $i = 0; ?>
								<?php foreach ( $page_id as $id ) : ?>
								<?php $page_data = get_page( $id ); ?>
								<tr>
									<th class="check-column" scope="row" align="center">
										<input id="aft-page-check-<?php echo $i; ?>" type="checkbox" name="aft-page-check-<?php echo $i; ?>" value="<?php echo $page_data->ID; ?>" <?php if ( $page_data->ID == $page_opt_id[$i] ) echo 'checked="checked"'; ?> />
									</th>
									<td><?php echo $page_data->ID; ?></td>
									<td><?php echo $page_data->post_title; ?></td>
									<td><?php echo $page_data->post_name; ?></td>
								</tr>
								<?php $i++; ?>
								<?php endforeach; ?>
							</tbody>
						</table>
						<div id="page-navigation"></div>
					</fieldset>
					<script type="text/javascript">
						var page_pager = new Pager('insertion-page', 10); 
						page_pager.init(); 
						page_pager.showPageNav('page_pager', 'page-navigation'); 
						page_pager.showPage(1);
					</script>
				</div>
				<?php endif; ?>
				<div class="rtp-label-top">
					<input class="button-secondary" name="submit-insertion" type="submit" value="<?php _e( 'Apply Insertion' ); ?>" />
				</div>
			</form>
		</div>
		<div id="rtp-reporting">
			<div>
				<?php
					if ( isset( $_REQUEST['submit-filter'] ) ) {
						$rate_data = aft_plgn_fetch_article_rate( $_POST['aft-filter'], $_POST['aft-by-insertion'] );
					} else {
						$rate_data = aft_plgn_fetch_article_rate(); //Show All
					}
				?>
				<form method="post" action="admin.php?page=<?php echo RTP_PLUGIN_SNAME; ?>#rtp-reporting">
					<div class="rtp-label-top">
						Filter By:&nbsp;
						<select name="aft-by-insertion" style="width: 80px;">
							<option <?php if ( $_POST['aft-by-insertion'] == 'post' ) echo 'selected="selected"'; ?> value="post">All Post</option>
							<option <?php if ( $_POST['aft-by-insertion'] == 'page' ) echo 'selected="selected"'; ?> value="page">All Page</option>
						</select>
						&nbsp;-&nbsp;
						<select name="aft-filter" style="width: 120px;">
							<option <?php if ( $_POST['aft-filter'] == 'all' ) echo 'selected="selected"'; ?> value="all">All Rated</option>
							<option <?php if ( $_POST['aft-filter'] == 'highest' ) echo 'selected="selected"'; ?> value="highest">Highest Rated</option>
							<option <?php if ( $_POST['aft-filter'] == 'lowest' ) echo 'selected="selected"'; ?> value="lowest">Lowest Rated</option>
							<option <?php if ( $_POST['aft-filter'] == 'last-update' ) echo 'selected="selected"'; ?> value="last-update">Last Updated</option>							
						</select>
						<input class="button-secondary" name="submit-filter" type="submit" value="<?php _e( 'Filter' ); ?>" />
					</div>
					<div style="clear: both;"></div>
					<table id="report-result" class="tablesorter">
						<thead>
							<tr>
								<th>ID</th>
								<th>Title</th>
								<th>Trustworthy</th>
								<th>Objective</th>
								<th>Complete</th>
								<th>Well-written</th>
								<?php if ( $_POST['aft-filter'] != 'last-update' ) : ?>
								<th>Ave. Rating</th>
								<?php else : ?>
								<th>Date Modified</th>
								<?php endif; ?>
							</tr>
						</thead>
						<tbody>
							<?php if ( $rate_data ) : ?>
							<?php foreach ( $rate_data as $rows ) : ?>
							<tr valign="top">
								<td><?php echo $rows->post_id; ?></td>
								<td>
									<div class="rtp-title">
										<a class="rtp-post-title" href="<?php echo admin_url(); ?>post.php?post=<?php echo $rows->post_id ?>&action=edit"><?php echo $rows->post_title; ?></a>
									</div>
								</td>
								<td><?php echo $rows->trustworthy_rate; ?></td>
								<td><?php echo $rows->objective_rate; ?></td>
								<td><?php echo $rows->complete_rate; ?></td>
								<td><?php echo $rows->wellwritten_rate; ?></td>
								<?php if ( $_POST['aft-filter'] != 'last-update' ) : ?>
								<td><?php echo $rows->rate_average; ?></td>
								<?php else : ?>
								<td><?php echo $rows->rate_modified; ?></td>
								<?php endif; ?>
							</tr>
							<?php endforeach; ?>
							<?php endif; ?>
						</tbody>
					</table>
					<div id="pagenavigation"></div>
				</form>
				<script type="text/javascript">
					var pager = new Pager('report-result', 10); 
					pager.init(); 
					pager.showPageNav('pager', 'pagenavigation'); 
					pager.showPage(1);
				</script>
			</div>
			<div style="clear: both;"></div>
			<div id="note" class="corners">
				<b>Average Rating Formula:</b>
					If there are five (5) people voted for trustworthy and rated 5.0, then the average rating is 5.0 because the article's vote is weighted by the number of people's ratings.
					Now, if there are five (5) people voted for trustworthy and rated 5.0, then another person voted 1.0 to its rating, then the average rating is 4.3.
				<br /><br /><b>In short:</b>
					The total number of rating's namely: Trustworthy, Objective, Complete and Well-written is divided by the number of people who rated the article = Average Rating.
				<br /><br />And, the posts with the average rating of 3.5 up are listed in Highest Rated and below 3.5 are listed in Lowest Rated.
			</div>
		</div>
		<div id="rtp-db-configuration">
			<div>
				<form method="post" action="admin.php?page=<?php echo RTP_PLUGIN_SNAME; ?>#rtp-db-configuration" enctype="multipart/form-data">
					<table class="rtp-form-table">
						<tr>
							<th class="rtp-p">Table Installation:</th>
							<td>
							<?php if ( $wpdb->get_var("SHOW TABLES LIKE '$tbl_feedbacks'") != $tbl_feedbacks 
									&& $wpdb->get_var("SHOW TABLES LIKE '$tbl_feedbacks_summary'") != $tbl_feedbacks_summary ) : ?>
							<input class="button-secondary" name="rtp-install-table" type="submit" value="<?php _e( 'Install' ); ?>" />
							<?php else : ?>
							<input class="button-secondary" name="rtp-uninstall-table" type="submit" value="<?php _e( 'Uninstall' ); ?>" />
							<?php endif; ?>
							</td>
						</tr>
						<tr><p class="rtp-p">All database tables will be deleted. This procedure is not reversible. <br />Backup the database (this plugin use wp-feedbacks and wp-feedbacks-summary in phpMyAdmin) if you are in process of migration and want to restore the report ratings later.</p></tr>
					</table>
				</form>
			</div>
		</div>
	</div>
</div>
<div class="corners">
	<?php global $wpdb; ?>
	<?php $tbl_feedbacks = $wpdb->prefix . "feedbacks"; ?>
	<?php $tbl_feedbacks_summary = $wpdb->prefix . "feedbacks_summary"; ?>
	<?php if ( $wpdb->get_var("SHOW TABLES LIKE '$tbl_feedbacks'") != $tbl_feedbacks 
			&& $wpdb->get_var("SHOW TABLES LIKE '$tbl_feedbacks_summary'") != $tbl_feedbacks_summary ) : ?>
			<p class='rtp-p rtp-bg corners'><b>Warning:<b><br />
			<i>No tables found inside the database.<br />
			Please go to Database Configuration Tab then (Click Install) to install
			the required database tables.</i></p>
	<?php endif; ?>
</div>
		<?php
	}
}
?>