<?php
/**
 * Initialize cookie
 *
 * @return void
 */
if ( !function_exists( 'aft_init_cookie' ) ) {
	function aft_init_cookie() {
		$cookie_value = 'guest-'.rand( RTP_COOKIE_RANDMIN, RTP_COOKIE_RANDMAX );
		
		// Trap and generate again if cookie matched in session key inside the table.
		if ( rtp_cookie_is_match( $cookie_value ) ) {
			$cookie_value = 'guest-'.rand( RTP_COOKIE_RANDMIN, RTP_COOKIE_RANDMAX );
		}

		if ( !isset( $_COOKIE[ RTP_COOKIE_NAME ] ) && empty( $_COOKIE[ RTP_COOKIE_NAME ] ) ) {
			setcookie( RTP_COOKIE_NAME, $cookie_value, RTP_COOKIE_EXPIRATION, SITECOOKIEPATH, COOKIE_DOMAIN );
			
			//$_COOKIE var accepts immediately the value so it will be retrieved on page first load.
			$_COOKIE[ RTP_COOKIE_NAME ] = $cookie_value;
		}
	}
}

/**
 * When activated this function will create the admin menu and other initializations
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_load' ) ) {
	function aft_plgn_load() {
		add_menu_page( RTP_PLUGIN_NAME.' Main', RTP_PLUGIN_NAME, 'administrator', RTP_PLUGIN_SNAME, 'rtp_plgn_main_menu',  RTP_PLUGIN_DIR_IMG . 'AFT_icon-16.png' );
		
		//Create options for this plugin.
		add_action( 'admin_init', 'aft_plgn_options' );
		add_action( 'admin_print_styles', 'aft_plgn_css_init' );
		add_action( 'admin_print_scripts', 'aft_plgn_jquery_init' );
	}
}

/**
 * jQuery initialization function
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_jquery_init' ) ) {
	function aft_plgn_jquery_init() {
		// Register and enqueue jquery libraries
		if ( is_admin() ) {
			wp_register_script( 'jquery-min',  RTP_PLUGIN_DIR_JS . 'jquery.min.js' );
			wp_register_script( 'jquery-ui',  RTP_PLUGIN_DIR_JS . 'jquery-ui.min.js' );
			wp_register_script( 'jquery-tablesorter',  RTP_PLUGIN_DIR_JS . 'jquery.tablesorter.min.js' );
			wp_register_script( 'jquery-tablesorter-pager',  RTP_PLUGIN_DIR_JS . 'jquery.tablesorter.pager.js' );
			wp_register_script( 'jquery-paging',  RTP_PLUGIN_DIR_JS . 'paging.js' );
			wp_enqueue_script( 'jquery-min' );
			wp_enqueue_script( 'jquery-ui' );
			wp_enqueue_script( 'jquery-tablesorter' );
			wp_enqueue_script( 'jquery-tablesorter-pager' );
			wp_enqueue_script( 'jquery-paging' );
		} else {
			wp_register_script( 'jquery-min',  RTP_PLUGIN_DIR_JS . 'jquery.min.js' );
			wp_register_script( 'jquery-raty-min',  RTP_PLUGIN_DIR_JS . 'jquery.raty.min.js' );
			wp_register_script( 'jquery-feedback',  RTP_PLUGIN_DIR_JS . 'feedback.js' );
			wp_enqueue_script( 'jquery-min' );
			wp_enqueue_script( 'jquery-raty-min' );
			wp_enqueue_script( 'jquery-feedback' );
		}
	}
}

/**
 * CSS initialization function
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_css_init' ) ) {
	function aft_plgn_css_init() {
		// Register and enqueue style sheets.
		if ( is_admin() ) {
			wp_register_style( 'jquery-ui',  RTP_PLUGIN_DIR_CSS . 'jquery-ui.css' );
			wp_register_style( 'feedback-admin-ui',  RTP_PLUGIN_DIR_CSS . 'feedback-admin.css' );
			wp_register_style( 'feedback-tablesorter-pager',  RTP_PLUGIN_DIR_CSS . 'jquery.tablesorter.pager.css' );
			wp_register_style( 'feedback-tablesorter-theme',  RTP_PLUGIN_DIR_CSS . 'blue/style.css' );
			wp_enqueue_style( 'jquery-ui' );
			wp_enqueue_style( 'feedback-admin-ui' );
			wp_enqueue_style( 'feedback-tablesorter-pager' );
			wp_enqueue_style( 'feedback-tablesorter-theme' );
		} else {
			wp_register_style( 'feedback-style-sheet', RTP_PLUGIN_DIR_CSS . 'feedback.css' );
			wp_enqueue_style( 'feedback-style-sheet' );
		}
	}
}

/**
 * Initialize options for this plugin
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_options' ) ) {
	function aft_plgn_options() {
		global $aft_options_array, $aft_options_by_array;
		
		$cat_id = get_all_category_ids();
		$page_id = get_all_page_ids();
		
		$post_value = 0;
		$options_category = array();
		$options_page = array();
		
		if ( $cat_id ) {
			foreach( $cat_id as $id ) {
				$options_category[get_cat_name($id)] = $post_value;
			}
		}
		
		if ( $page_id ) {
			foreach( $page_id as $id ) {
				$page_data = get_page( $id );
				$options_page[$page_data->post_title] = $post_value;
			}
		}
		
		// Default setup for option variable
		$aft_options_list = array(
			'aft_is_enable'			=>	'true',
			'aft_location'			=>	'bottom',
			'aft_insertion'			=>	'all-article',
		);
		
		if ( !get_option( 'aft_options_array' ) ) {
			add_option( 'aft_options_array', $aft_options_list, '', 'yes' );
		}
		
		$options_by_category = array( array( $options_category ) );
		$options_by_page = array( array( $options_page ) );
		
		$aft_options_by_list = array(
			'category'			=> array( $options_by_category ),
			'page'				=> array( $options_by_page ),
		);
			
		if ( !get_option( 'aft_options_by_array' ) ) {
			add_option( 'aft_options_by_array', $aft_options_by_list, '', 'yes' );
		}
			
		$aft_options_array = get_option( 'aft_options_array' );
		$aft_options_by_array = get_option( 'aft_options_by_array' );
	}
}
/**
 * Function to remove the options that was saved.
 * This function will be called once the register_deactivation_hook( __FILE__, 'aft_plgn_remove_options' )
 * is uncomment in rtp-load.php
 *
 * But for safety purposes I think this will not be called.
 *
 * @param string $message
 * @param array @options
 * @param array @options_by
 *
 * @return void
 */
// If plugin deactivated remove options stored in database.
if ( !function_exists( 'aft_plgn_remove_options' ) ) {
	function aft_plgn_remove_options() {
		delete_option( 'aft_options_array' );
		delete_option( 'aft_options_by_array' );
	}
}
?>