<?php
/**
 * Fetch ratings result
 *
 * @param string $post_id
 * @param string $session_key
 * @param string $is_page
 *
 * @return object
 */
if ( !function_exists( 'aft_plgn_fetch_ratings' ) ) {
	function aft_plgn_fetch_ratings( $post_id = null, $session_key = null, $is_page = null ) {
		global $wpdb;
		
		if ( !empty( $post_id ) && !empty( $session_key ) && !empty( $is_page ) ) {
				// Fetch data by session key and post id.
				// Additional where clause is if the fetched data is from a page.
				$sql = sprintf( "SELECT * FROM %sfeedbacks
								WHERE post_id = %s AND session_key = '%s' AND is_page = '%s'",
								$wpdb->prefix, $post_id, $session_key, $is_page );
				$aft_get_result = $wpdb->get_row( $sql );
		}
		
		return $aft_get_result;
	}
}

/**
 * Save function for rated posts/pages
 *
 * @param bool $isnew
 * @param array $aft_data
 * @param string $post_id
 * @param string $session_key
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_save_ratings' ) ) {
	function aft_plgn_save_ratings( $isnew, $aft_data, $post_id = null, $session_key = null ) {		
		global $wpdb;
		
		if ( !empty( $aft_data ) ) {
			if ( !$isnew ) {
				// Apply values for where clause
				if ( !empty( $post_id ) && !empty( $session_key ) ) {
					$where = array(
						'post_id' => $post_id,
						'session_key' => $session_key,
						'is_page' => $aft_data['is_page'], // include is_page to avoid updating conflict.
					);
				}
			
				// Apply date and time for updated rating of article.
				$aft_data['rate_modified'] = current_time('mysql');
			
				// Before updating the data in wp_feedbacks store first old data's.
				$aft_old_data = aft_plgn_fetch_ratings( $post_id, $session_key, $aft_data['is_page'] );
			
				$sql = sprintf( '%sfeedbacks', $wpdb->prefix );
				$wpdb->update( $sql, $aft_data, $where );
			} else {
				// Apply date and time for rated article.
				if ( isset( $aft_data['rate_date'] ) ) {
					$aft_data['rate_date'] = current_time('mysql');
				}
				
				$sql = sprintf( '%sfeedbacks', $wpdb->prefix );
				$wpdb->insert( $sql, $aft_data );
			}
			
			aft_plgn_calculate_summary( $aft_data,
										aft_plgn_fetch_rate_summary( 
														( !empty( $post_id ) ) ? $post_id : $aft_data['post_id'],
														$aft_data['is_page']
										),
										$session_key,
										$isnew,
										$aft_old_data );
		}
	}
}

/**
 * Calculate the overall average of the rated posts and pages
 *
 * @param array $aft_data
 * @param array $aft_fetch_data
 * @param string $session_key
 * @param bool $isnew
 * @param array $aft_old_data
 *
 * @return void
 */
if ( !function_exists( 'aft_plgn_calculate_summary' ) ) {
	function aft_plgn_calculate_summary( $aft_data, $aft_fetch_data, $session_key, $isnew,  $aft_old_data = null ) {
		global $wpdb;
		
		// Initialize value for declared variables.
		$post_id = $aft_data['post_id'];
		$total_trustworthy = $aft_data['trustworthy_rate'];
		$total_objective = $aft_data['objective_rate'];
		$total_complete = $aft_data['complete_rate'];
		$total_wellwritten = $aft_data['wellwritten_rate'];
		$is_page = $aft_data['is_page']; // Identify if the summary stored is a page rated summary.
		
		$count_trustworthy = 1;
		$count_objective = 1;
		$count_complete = 1;
		$count_wellwritten = 1;	
		
		// Check if post_id already exist in wp_feedbacks_summary table.
		if ( $aft_fetch_data->post_id != 0 ) {
			if ( !$isnew ) {
				// Sum of total rate from users for Trustworthy Rating.
				if ( $aft_data['trustworthy_rate'] <= $aft_old_data->trustworthy_rate ) {
					$temp_total = intval($aft_old_data->trustworthy_rate - $aft_data['trustworthy_rate']);
					$total_trustworthy = intval($aft_fetch_data->total_trustworthy - $temp_total);
				} else {
					$temp_total = intval($aft_data['trustworthy_rate'] - $aft_old_data->trustworthy_rate );
					$total_trustworthy = intval($aft_fetch_data->total_trustworthy + $temp_total);
				}
				
				// Sum of total rate from users for Objective Rating.
				if ( $aft_data['objective_rate'] <= $aft_old_data->objective_rate ) {
					$temp_total = intval($aft_old_data->objective_rate - $aft_data['objective_rate']);
					$total_objective = intval($aft_fetch_data->total_objective - $temp_total);
				} else {
					$temp_total = intval($aft_data['objective_rate'] - $aft_old_data->objective_rate );
					$total_objective = intval($aft_fetch_data->total_objective + $temp_total);
				}
				
				// Sum of total rate from users for Complete Rating.
				if ( $aft_data['complete_rate'] <= $aft_old_data->complete_rate ) {
					$temp_total = intval($aft_old_data->complete_rate - $aft_data['complete_rate']);
					$total_complete = intval($aft_fetch_data->total_complete - $temp_total);
				} else {
					$temp_total = intval($aft_data['complete_rate'] - $aft_old_data->complete_rate );
					$total_complete = intval($aft_fetch_data->total_complete + $temp_total);
				}
				
				// Sum of total rate from users for Well-written Rating.
				if ( $aft_data['wellwritten_rate'] <= $aft_old_data->wellwritten_rate ) {
					$temp_total = intval($aft_old_data->wellwritten_rate - $aft_data['wellwritten_rate']);
					$total_wellwritten = intval($aft_fetch_data->total_wellwritten - $temp_total);
				} else {
					$temp_total = intval($aft_data['wellwritten_rate'] - $aft_old_data->wellwritten_rate );
					$total_wellwritten = intval($aft_fetch_data->total_wellwritten + $temp_total);
				}
				
				$count_trustworthy = $aft_fetch_data->count_trustworthy;
				$count_objective = $aft_fetch_data->count_objective;
				$count_complete = $aft_fetch_data->count_complete;
				$count_wellwritten = $aft_fetch_data->count_wellwritten;
			} else {
				$total_trustworthy = intval($aft_fetch_data->total_trustworthy + $aft_data['trustworthy_rate']);
				$total_objective = intval($aft_fetch_data->total_objective + $aft_data['objective_rate']);
				$total_complete = intval($aft_fetch_data->total_complete + $aft_data['complete_rate']);
				$total_wellwritten = intval($aft_fetch_data->total_wellwritten + $aft_data['wellwritten_rate']);
				
				$count_trustworthy += $aft_fetch_data->count_trustworthy;
				$count_objective += $aft_fetch_data->count_objective;
				$count_complete += $aft_fetch_data->count_complete;
				$count_wellwritten += $aft_fetch_data->count_wellwritten;
			}
		}
		
		// Place all supplied variable in an array.
		$aft_sdata = array(
			'post_id'			 	=> $post_id,
			'total_trustworthy' 	=> $total_trustworthy,
			'count_trustworthy' 	=> $count_trustworthy,
			'total_objective' 		=> $total_objective,
			'count_objective' 		=> $count_objective,
			'total_complete' 		=> $total_complete,
			'count_complete' 		=> $count_complete,
			'total_wellwritten' 	=> $total_wellwritten,
			'count_wellwritten' 	=> $count_wellwritten,
			'is_page'				=> $is_page,
		);
		
		// Compute overall average rating of the article that was rated.
		$trustworthy_ave = $total_trustworthy / $count_trustworthy;
		$objective_ave = $total_objective / $count_objective;
		$complete_ave = $total_complete / $count_complete;
		$wellwritten_ave = $total_wellwritten / $count_wellwritten;
		
		$overall_ave = array( $trustworthy_ave, $objective_ave, $complete_ave, $wellwritten_ave );
		$aft_sdata['rate_average'] = array_sum( $overall_ave ) / count( $overall_ave );
		
		// Check if post_id not exist in wp_feedbacks_summary table.
		if ( $aft_fetch_data->post_id == 0 ) {
			$sql = sprintf( '%sfeedbacks_summary', $wpdb->prefix );
			$wpdb->insert( $sql, $aft_sdata );
		} else {
			// The summary of the page being rated.
			if ( $aft_fetch_data->is_page == 'true' ) {
				$sql = sprintf( '%sfeedbacks_summary', $wpdb->prefix );
				$wpdb->update( $sql, $aft_sdata, array( 'post_id' => $aft_data['post_id'], 'is_page' => $aft_data['is_page'] ) );
			} else {
				$sql = sprintf( '%sfeedbacks_summary', $wpdb->prefix );
				$wpdb->update( $sql, $aft_sdata, array( 'post_id' => $aft_data['post_id'] ) );
			}
		}
	}
}

/**
 * Fetch the article that was rated with its average and total average.
 *
 * @param string $filter
 *
 * @return object
 */
if ( !function_exists( 'aft_plgn_fetch_article_rate' ) ) {
	function aft_plgn_fetch_article_rate( $filter = null, $insertion = 'post' ) {
		global $wpdb;
		
		switch ( $filter ) {
			case "highest":
				$_sql = "SELECT post_id, post_title,
						CAST((total_trustworthy / count_trustworthy) AS decimal(3,2)) AS trustworthy_rate ,
						CAST((total_objective / count_objective) AS decimal(3,2)) AS objective_rate,
						CAST((total_complete / count_complete) AS decimal(3,2)) AS complete_rate,
						CAST((total_wellwritten / count_wellwritten) AS decimal(3,2)) AS wellwritten_rate, rate_average
						FROM %sfeedbacks_summary
						INNER JOIN $wpdb->posts ON $wpdb->posts.id = %sfeedbacks_summary.post_id
						WHERE rate_average >= 3.5";
				if ( $insertion == 'page' ) {
					$_sql .= " AND is_page = 'true'";
				} else {
					$_sql .= " AND is_page = 'false'";
				}
				$_sql .= " ORDER BY rate_average DESC";
				$sql = sprintf( $_sql, $wpdb->prefix, $wpdb->prefix, $wpdb->prefix );
				break;
			case "lowest":
				$_sql = "SELECT post_id, post_title,
						CAST((total_trustworthy / count_trustworthy) AS decimal(3,2)) AS trustworthy_rate ,
						CAST((total_objective / count_objective) AS decimal(3,2)) AS objective_rate,
						CAST((total_complete / count_complete) AS decimal(3,2)) AS complete_rate,
						CAST((total_wellwritten / count_wellwritten) AS decimal(3,2)) AS wellwritten_rate, rate_average
						FROM %sfeedbacks_summary
						INNER JOIN $wpdb->posts ON $wpdb->posts.id = %sfeedbacks_summary.post_id
						WHERE rate_average <= 3.5";
				if ( $insertion == 'page' ) {
					$_sql .= " AND is_page = 'true'";
				} else {
					$_sql .= " AND is_page = 'false'";
				}
				$_sql .= " ORDER BY rate_average DESC";
				$sql = sprintf( $_sql, $wpdb->prefix, $wpdb->prefix, $wpdb->prefix );
				break;
			case "last-update":
				//$date_begin = date('Y-m-d') . " 00:00:00";
				//$date_end = date('Y-m-d') . " 23:59:59";
				
				$_sql = "SELECT %sfeedbacks.id as fid, post_id, post_title, trustworthy_rate, 
						objective_rate, complete_rate, wellwritten_rate, rate_modified
						FROM %sfeedbacks
						INNER JOIN $wpdb->posts ON $wpdb->posts.id = %sfeedbacks.post_id";
				if ( $insertion == 'page' ) {
					$_sql .= " WHERE is_page = 'true'";
				} else {
					$_sql .= " WHERE is_page = 'false'";
				}
				$_sql .= " ORDER BY rate_modified DESC";
				$sql = sprintf( $_sql, $wpdb->prefix, $wpdb->prefix, $wpdb->prefix, $date_begin, $date_end );
				break;
			case "all":
			default:
				$_sql = "SELECT post_id, post_title,
						CAST((total_trustworthy / count_trustworthy) AS decimal(3,2)) AS trustworthy_rate ,
						CAST((total_objective / count_objective) AS decimal(3,2)) AS objective_rate,
						CAST((total_complete / count_complete) AS decimal(3,2)) AS complete_rate,
						CAST((total_wellwritten / count_wellwritten) AS decimal(3,2)) AS wellwritten_rate, rate_average
						FROM %sfeedbacks_summary
						INNER JOIN $wpdb->posts ON $wpdb->posts.id = %sfeedbacks_summary.post_id";
				if ( $insertion == 'page' ) {
					$_sql .= " WHERE is_page = 'true'";
				} else {
					$_sql .= " WHERE is_page = 'false'";
				}
				$_sql .= " ORDER BY rate_average DESC";
				$sql = sprintf( $_sql, $wpdb->prefix, $wpdb->prefix, $wpdb->prefix );
				break;
		}
		$aft_get_result = $wpdb->get_results( $sql );
		
		return $aft_get_result;
	}
}

/**
 * Fetch the summary of the rated post/article
 *
 * @param string $post_id
 *
 * @return object
 */
if ( !function_exists( 'aft_plgn_fetch_rate_summary' ) ) {
	function aft_plgn_fetch_rate_summary( $post_id, $is_page ) {
		global $wpdb;
		
		$sql = sprintf( "SELECT * FROM %sfeedbacks_summary WHERE post_id = %s AND is_page = '%s'",
						$wpdb->prefix, $post_id, $is_page );
		$aft_get_result = $wpdb->get_row( $sql );
		
		return $aft_get_result;
	}
}

/**
 * Fetch the if cookie already generated and exists inside the table to avoid duplication.
 *
 * @param string $cookie
 *
 * @return bool
 */
if ( !function_exists( 'rtp_cookie_is_match' ) ) {
	function rtp_cookie_is_match( $cookie ) {
		global $wpdb;
		
		$sql = sprintf( "SELECT session_key FROM %sfeedbacks
						WHERE user_type = 0 AND session_key = '%s'", $wpdb->prefix, $cookie );
		$sql_col = $wpdb->get_col( $sql );
		
		if ( $sql_col ) {
			$ret = true;
		} else {
			$ret = false;
		}
		
		return $ret;
	}
}
?>